/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.valueprovider;

import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EFactory;
import org.eclipse.emf.ecore.EStructuralFeature;

/**
 * Descriptor for a single {@link EStructuralFeature} (used in
 * {@link EStructuralFeatureValueProviderBase} to support multiple {@link EStructuralFeature}s
 * contained in a single {@link EClass}.
 */
public class EStructuralFeatureDescriptor {
	/** Reference to {@link EStructuralFeature}. */
	private EStructuralFeature structuralFeature;

	/** {@link EFactory} used to initialize {@link EStructuralFeature}. */
	EFactory structuralFeatureFactory;

	/** Default value used to initialize {@link EStructuralFeature}. */
	String structuralFeatureDefaultValue;

	/** Generates a descriptor for a single {@link EStructuralFeature}. */
	public EStructuralFeatureDescriptor(EStructuralFeature structuralFeature,
			EFactory structuralFeatureFactory, String structuralFeatureDefaultValue) {
		this.structuralFeature = structuralFeature;
		this.structuralFeatureFactory = structuralFeatureFactory;
		this.structuralFeatureDefaultValue = structuralFeatureDefaultValue;
	}

	/** Returns structuralFeature. */
	public EStructuralFeature getStructuralFeature() {
		return structuralFeature;
	}

	/** Returns structuralFeatureFactory. */
	public EFactory getStructuralFeatureFactory() {
		return structuralFeatureFactory;
	}

	/** Returns structuralFeatureDefaultValue. */
	public String getStructuralFeatureDefaultValue() {
		return structuralFeatureDefaultValue;
	}

}
