/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.valueprovider;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EEnum;
import org.eclipse.emf.ecore.EEnumLiteral;
import org.eclipse.emf.ecore.EFactory;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.EditingSupport;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;
import org.fortiss.tooling.base.ui.annotation.editingsupport.ComboBoxEditingSupport;

/**
 * Base class for {@link IAnnotationValueProvider}s that manages a single enumeration contained in a
 * {@link IAnnotatedSpecification}. The provider will provide a {@link ComboBoxEditingSupport} that
 * is initialized to the enumeration value names specified in the respective ECore model
 * containing the enumeration type.
 * 
 * @author barner
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash:
 */
public abstract class SingleEnumAttributeValueProviderBase<T extends IAnnotatedSpecification>
		extends EStructuralFeatureValueProviderBase<T> {

	/** Data type of the enumeration managed by this {@link IAnnotationValueProvider} */
	private EEnum eEnum;

	/**
	 * Constructs a {@link IAnnotationValueProvider} for a {@link IAnnotatedSpecification} that
	 * that that manages a single enumeration attribute contained in a
	 * {@link IAnnotatedSpecification}. The enumeration attribute is initialized to its default
	 * value.
	 */
	public SingleEnumAttributeValueProviderBase(EClass annotatedSpecificationEClass,
			EFactory annotationFactory, EAttribute attribute, EEnum eEnum, EFactory attributeFactory) {
		this(annotatedSpecificationEClass, annotationFactory, attribute, eEnum, attributeFactory,
				null);
	}

	/**
	 * Constructs a {@link IAnnotationValueProvider} for a {@link IAnnotatedSpecification} that
	 * that that manages a single enumeration attribute contained in a
	 * {@link IAnnotatedSpecification}. The constructor assumes that the
	 * {@code attributeDefaultValue} matches of the enumeration names.
	 */
	public SingleEnumAttributeValueProviderBase(EClass annotatedSpecificationEClass,
			EFactory annotationFactory, EAttribute attribute, EEnum eEnum,
			EFactory attributeFactory, final String attributeDefaultValue) {
		super(annotatedSpecificationEClass, annotationFactory, attribute, attributeFactory,
				attributeDefaultValue);
		this.eEnum = eEnum;
	}

	/** {@inheritDoc} */
	@Override
	public EditingSupport createEditingSupport(ColumnViewer viewer,
			Class<? extends IAnnotatedSpecification> clazz, String instanceKey) {

		List<String> enumValues = new ArrayList<String>();
		for(EEnumLiteral e : eEnum.getELiterals()) {
			enumValues.add(e.getName());
		}

		return new ComboBoxEditingSupport(viewer, clazz, enumValues, false);
	}
}
